@@ -1,9 +1,8 @@
-import asyncio
 import inspect
 from typing import Any, Awaitable, Callable, Optional, TypeVar, Generic, Union
 
 from mediatr.exceptions import raise_if_behavior_is_invalid, raise_if_handler_is_invalid, raise_if_handler_not_found, \
-    raise_if_request_invalid
+    raise_if_request_none
 
 __handlers__ = {}
 __behaviors__ = {}
@@ -17,7 +16,16 @@ def default_handler_class_manager(HandlerCls:type,is_behavior:bool=False):
 
 def extract_request_type(handler, is_behavior=False) -> type:
     isfunc = inspect.isfunction(handler)
-    func = handler if isfunc else (handler.handle if hasattr(handler, 'handle') else None)
+    
+    func = None
+    if isfunc:
+        func = handler
+    else:
+        if hasattr(handler, 'handle'):
+            if inspect.isfunction(handler.handle):
+                func = handler.handle
+            elif inspect.ismethod(handler.handle):
+                func = handler.__class__.handle
 
     if is_behavior:
         raise_if_behavior_is_invalid(handler)
@@ -66,9 +74,13 @@ class Mediator():
         self1 = Mediator if not request else self
         request = request or self
 
-        raise_if_request_invalid(request)
-        handler = __handlers__[request.__class__] if __handlers__.get(request.__class__) else None
-        raise_if_handler_not_found(handler, __handlers__)
+        raise_if_request_none(request)
+        handler = None
+        if __handlers__.get(request.__class__):
+            handler = __handlers__[request.__class__]
+        elif __handlers__.get(request.__class__.__name__):
+            handler =__handlers__[request.__class__.__name__]
+        raise_if_handler_not_found(handler,request)
         handler_func = None
         handler_obj = None
         if inspect.isfunction(handler):
@@ -109,9 +121,13 @@ class Mediator():
         self1 = Mediator if not request else self
         request = request or self
 
-        raise_if_request_invalid(request)
-        handler = __handlers__[request.__class__] if __handlers__.get(request.__class__) else None
-        raise_if_handler_not_found(handler, __handlers__)
+        raise_if_request_none(request)
+        handler = None
+        if __handlers__.get(request.__class__):
+            handler = __handlers__[request.__class__]
+        elif __handlers__.get(request.__class__.__name__):
+            handler =__handlers__[request.__class__.__name__]
+        raise_if_handler_not_found(handler,request)
         handler_func = None
         handler_obj = None
         if inspect.isfunction(handler):
